@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-#    Copyright (C) 2011-2019 Luis Falcon <falcon@gnuhealth.org>
-#    Copyright (C) 2011-2019 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2011-2020 Luis Falcon <falcon@gnuhealth.org>
+#    Copyright (C) 2011-2020 GNU Solidario <health@gnusolidario.org>
 #    Copyright (C) 2011 Cédric Krier
 
 #    This program is free software: you can redistribute it and/or modify
@@ -34,7 +34,7 @@ for key in ('depends', 'extras_depend', 'xml'):
         info[key] = info[key].strip().splitlines()
 major_version, minor_version = 5, 0
 
-requires = ['pytz','numpy']
+requires = ['pytz','numpy','matplotlib']
 
 for dep in info.get('depends', []):
     if (dep == 'health'):
